NiceBaseListBodyChildSeparatedIndexedBuilderDelegate<D> class

Implemented types

Constructors

NiceBaseListBodyChildSeparatedIndexedBuilderDelegate({required Widget builder(BuildContext context, D data, int absoluteIndex, int relativeIndex), required WidgetBuilder separatorBuilder})
const

Properties

builder Widget Function(BuildContext context, D data, int absoluteIndex, int relativeIndex)
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
separatorBuilder WidgetBuilder
final

Methods

build(BuildContext context, D data, int absoluteIndex, int relativeIndex, NiceBaseListConfigData config) Widget
Builds the child that will be displayed in the list body.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited