NicePageViewFormBaseValidationStrategy class abstract

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isValid(BuildContext context) FutureOr<bool>
Called when the user presses the next button This method can have side effects, such as calling the markAllAsTouched method on a FormGroup
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited