NicePageViewFormFormGroupValidationStrategy class

Implemented types

Constructors

NicePageViewFormFormGroupValidationStrategy({String? abstractControlName, AbstractControl? abstractControl, bool markAllAsTouchedIfInvalid = true})
const

Properties

abstractControl → AbstractControl?
final
abstractControlName String?
final
hashCode int
The hash code for this object.
no setterinherited
markAllAsTouchedIfInvalid bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isValid(BuildContext context) FutureOr<bool>
Called when the user presses the next button This method can have side effects, such as calling the markAllAsTouched method on a FormGroup
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited