NiceSignInState class

Inheritance

Constructors

NiceSignInState({required bool loading, required bool error, required bool invalidCredentials})
const
NiceSignInState.initialState()
const

Properties

error bool
finalinherited
hashCode int
The hash code for this object.
no setterinherited
invalidCredentials bool
Whether the user entered invalid credentials
final
loading bool
finalinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

copyWith({bool? loading, bool? error, bool? invalidCredentials}) NiceSignInState
copyWithLoadingAndError({bool? loading, bool? error}) NiceBaseState
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited