NiceSignInEmailPasswordButton<SocialProviders> class
Button that will call NiceSignInCubit.signInWithPassword Must be used in combination with NiceSignIn, NiceSignInEmailField and NiceSignInPasswordField
The SocialProviders type must be provided and be the same type as the one passed to NiceSignInCubit
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- NiceSignInEmailPasswordButton
Constructors
- NiceSignInEmailPasswordButton({Key? key, required NiceButtonTypes type, ButtonStyle? style, required String text, TextStyle? textStyle, bool showLoading = true, double loadingLineWidth = 3, Color? loadingLineColor})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- loadingLineColor → Color?
-
Line color of the loading spinner, if showLoading is true
final
- loadingLineWidth → double
-
Line width of the loading spinner, if showLoading is true
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showLoading → bool
-
Show a loading spinner in the button
final
- style → ButtonStyle?
-
Style of the button
final
- text → String
-
Text to be displayed in the button, e.g. "Sign in"
final
- textStyle → TextStyle?
-
Style of the text
final
- type → NiceButtonTypes
-
Type of button to be displayed
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited