NiceSignInPasswordField<SocialProviders> class
ReactiveTextField that will automatically bind to the FormGroup of NiceSignInCubit provided in NiceSignIn
Must be used in combination with NiceSignIn, NiceSignInEmailField and NiceSignInEmailPasswordButton
The SocialProviders type must be provided and be the same type as the one passed to NiceSignInCubit
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- NiceSignInPasswordField
Constructors
-
NiceSignInPasswordField({Key? key, Map<
String, ValidationMessageFunction> ? validationMessages, InputDecoration decoration = const InputDecoration(), TextStyle? style, TextAlign textAlign = TextAlign.left, bool obscureText = true}) -
const
Properties
- decoration → InputDecoration
-
Decoration for the
ReactiveTextFieldfinal - hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- obscureText → bool
-
Whether we want to obscure text content or not
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → TextStyle?
-
Style of the input text
final
- textAlign → TextAlign
-
Alignment of the text inside the text field
final
-
validationMessages
→ Map<
String, ValidationMessageFunction> ? -
Validation messages that will be passed to the
ReactiveTextFieldfinal
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited