WorstBaseListCubit<D> class
- Inheritance
-
- Object
- NiceBaseCubit<
WorstBaseListState< D> > - WorstBaseListCubit
Constructors
-
WorstBaseListCubit({required WorstBaseListConfig<
D> config}) - WorstBaseListCubit.of(BuildContext context)
-
factory
Properties
-
config
→ WorstBaseListConfig<
D> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isClosed → bool
-
Whether the bloc is closed.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
state
→ WorstBaseListState<
D> -
The current state.
no setterinherited
-
stream
→ Stream<
WorstBaseListState< D> > -
The current stream of states.
no setterinherited
Methods
-
addError(
Object error, [StackTrace? stackTrace]) → void -
Reports an
errorwhich triggersonErrorwith an optional StackTrace.inherited -
close(
) → Future< void> -
Closes the instance.
This method should be called when the instance is no longer needed.
Once
closeis called, the instance can no longer be used.inherited -
emit(
WorstBaseListState< D> state) → void -
Updates the
stateto the providedstate.emitdoes nothing if thestatebeing emitted is equal to the currentstate.inherited -
load(
{bool loading = true}) → Future< void> -
loadMore(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onChange(
Change< WorstBaseListState< change) → voidD> > -
Called whenever a
changeoccurs with the givenchange. Achangeoccurs when a newstateis emitted.onChangeis called before thestateof thecubitis updated.onChangeis a great spot to add logging/analytics for a specificcubit.inherited -
onError(
Object error, StackTrace stackTrace) → void -
Called whenever an
erroroccurs and notifiesBlocObserver.onError.inherited -
removeQueryRule(
String id, {bool reloadData = true}) → Future< void> -
resetAndLoad(
) → Future< void> -
setData(
List< D> data) → void -
toString(
) → String -
A string representation of this object.
inherited
-
updateData(
D mapFunc(D)) → void -
updateOrder(
NiceFilterOrderModel? order) → Future< void> -
updateQuery(
NiceFilterQueryModel? query) → Future< void> -
updateQueryRule(
String id, NiceFilterQueryRuleModel ruleUpdater(NiceFilterQueryRuleModel? oldRule), {bool reloadData = true}) → Future< void> -
updateSearch(
NiceFilterSearchModel? search) → Future< void> -
upsertQueryRules(
List< NiceFilterQueryRuleModel> upsertedRules) → Future<void> -
wrap<
R> ({bool loading = true, required FutureOr< R> callback(), FutureOr<R?> onError(Object e)?}) → FutureOr<R?> -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited